#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-qualify-imported-names-plugin
version:              2.3.0.0
visibility:           public
id:
    hls-qualify-imported-names-plugin-2.3.0.0-2yx97JzdZAeCepGwrHZLbb

key:
    hls-qualify-imported-names-plugin-2.3.0.0-2yx97JzdZAeCepGwrHZLbb

license:              Apache-2.0
maintainer:           shenjonathan0@gmail.com
author:               Jonathan Shen
synopsis:
    A Haskell Language Server plugin that qualifies imported names

description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  79017cfcc59e1402709643b4e31ca7ad
exposed:              True
exposed-modules:      Ide.Plugin.QualifyImportedNames
import-dirs:
    /usr/lib/ghc-9.6.6/site-local/hls-qualify-imported-names-plugin-2.3.0.0

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/hls-qualify-imported-names-plugin-2.3.0.0

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/hls-qualify-imported-names-plugin-2.3.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-qualify-imported-names-plugin
hs-libraries:
    HShls-qualify-imported-names-plugin-2.3.0.0-2yx97JzdZAeCepGwrHZLbb

depends:
    aeson-2.2.2.0-mVpxNJADFA3tVhrw9PzvG base-4.18.2.1 containers-0.6.7
    deepseq-1.4.8.1 dlist-1.0-F3vtDhl0dJJ2wapcm5Bnp ghc-9.6.6
    ghcide-2.3.0.0-2s8rQV9irz21pyc5cIsIV0
    hls-graph-2.3.0.0-72RWBHkz19LC8RLM7o3sC0
    hls-plugin-api-2.3.0.0-JWlMOnERUdN8af70lHp5qp
    lens-5.3.5-KA5gcUGZYMJ4Yj2DW4uyDf
    lsp-2.2.0.0-AApQc3pMEos5GLRJ0i2B8c text-2.0.2 transformers-0.6.1.0
    unordered-containers-0.2.21-8KUdGsL7zFhFWAw4aaEQtP

haddock-interfaces:
    /usr/share/doc/haskell-hls-qualify-imported-names-plugin/html/hls-qualify-imported-names-plugin.haddock

haddock-html:
    /usr/share/doc/haskell-hls-qualify-imported-names-plugin/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

